"""
Tests localbuild.py
"""

import pytest

from brewblox_tools import localbuild

TESTED = localbuild.__name__


@pytest.fixture
def getenv_mock(mocker):
    return mocker.patch(TESTED + '.getenv')


@pytest.fixture
def check_output_mock(mocker):
    return mocker.patch(TESTED + '.check_output')


@pytest.fixture
def distcopy_mock(mocker):
    return mocker.patch(TESTED + '.distcopy.main')


@pytest.fixture
def deploy_docker_mock(mocker):
    return mocker.patch(TESTED + '.deploy_docker.main')


def test_localbuild(getenv_mock, check_output_mock, distcopy_mock, deploy_docker_mock):
    getenv_mock.side_effect = [
        '_name',
        '_context',
        '_file',
    ]
    check_output_mock.side_effect = [
        b'_branch\n',
        b'_OUTPUT STUFF'
    ]
    localbuild.main()
    assert distcopy_mock.call_count == 2
    assert deploy_docker_mock.call_count == 1


def test_name_error(getenv_mock):
    getenv_mock.return_value = None
    with pytest.raises(KeyError):
        localbuild.main()



#! /usr/bin/python3

from os import getenv
from subprocess import check_output

from brewblox_tools import deploy_docker, distcopy


def main():
    name = getenv('DOCKER_REPO')

    if not name:
        raise KeyError('Environment variable $DOCKER_REPO not found')

    context = getenv('DOCKER_CONTEXT', 'docker')
    file = getenv('DOCKER_FILE', 'amd/Dockerfile')
    branch = check_output('git rev-parse --abbrev-ref HEAD'.split()).decode().rstrip()

    sdist_result = check_output('python setup.py sdist'.split()).decode()
    print(sdist_result)

    distcopy.main('dist/ docker/dist/'.split())
    distcopy.main('config/ docker/config/'.split())
    deploy_docker.main([
        '--context', context,
        '--file', file,
        '--name', name,
        '--tags', branch,
        '--no-push'
    ])
